<?php
/**
 * @package     CMShortURL
 * @subpackage  com_cmshorturl
 * @copyright   Copyright (C) 2015 CMExtension Team http://www.cmext.vn/
 * @license     GNU General Public License version 2 or later
 */

defined('_JEXEC') or die;

/**
 * Helper class for com_cmshorturl.
 *
 * @package     CMShortURL
 * @subpackage  com_cmshorturl
 * @since       1.0.0
 */
class CMShortURLHelper extends JHelperContent
{
	/**
	 * Configure the Linkbar.
	 *
	 * @param   string  $vName  The name of the active view.
	 *
	 * @return  void
	 *
	 * @since   1.0.0
	 */
	public static function addSubmenu($vName)
	{
		$params = JComponentHelper::getParams('com_cmshorturl');

		JHtmlSidebar::addEntry(
			JText::_('COM_CMSHORTURL_SUBMENU_URLS'),
			'index.php?option=com_cmshorturl&view=urls',
			$vName == 'urls'
		);

		if ($params->get('utm_params', 0))
		{
			JHtmlSidebar::addEntry(
				JText::_('COM_CMSHORTURL_SUBMENU_SOURCES'),
				'index.php?option=com_cmshorturl&view=sources',
				$vName == 'sources'
			);

			JHtmlSidebar::addEntry(
				JText::_('COM_CMSHORTURL_SUBMENU_CONTENTS'),
				'index.php?option=com_cmshorturl&view=contents',
				$vName == 'contents'
			);

			JHtmlSidebar::addEntry(
				JText::_('COM_CMSHORTURL_SUBMENU_CAMPAIGNS'),
				'index.php?option=com_cmshorturl&view=campaigns',
				$vName == 'campaigns'
			);
		}

		if ($params->get('logging', 0))
		{
			JHtmlSidebar::addEntry(
				JText::_('COM_CMSHORTURL_SUBMENU_LOGS'),
				'index.php?option=com_cmshorturl&view=logs',
				$vName == 'logs'
			);
		}

		JHtmlSidebar::addEntry(
			JText::_('COM_CMSHORTURL_SUBMENU_ABOUT'),
			'index.php?option=com_cmshorturl&view=about',
			$vName == 'about'
		);
	}

	/**
	 * Genarate random string.
	 *
	 * @param   integer  $length    The lenght of the random string
	 * @param   string   $charType  Character types: alphabetic, numeric, or alphanumeric
	 *
	 * @return  string
	 *
	 * @since   1.0.0
	 */
	public static function generateRandomString($length = 5, $charType = 'alphabetic')
	{
		$length = (int) $length;

		if ($charType == 'alphabetic')
		{
			$chars = 'abcdefghijklmnopqrstuvwxyz';
		}
		elseif ($charType == 'numeric')
		{
			$chars = '0123456789';
		}
		else
		{
			$chars = '0123456789abcdefghijklmnopqrstuvwxyz';
		}

		$string = '';

		for ($i = 0; $i < (int) $length; $i++)
		{
			$string .= $chars[mt_rand(0, strlen($chars) - 1)];
		}

		return $string;
	}

	/**
	 * Help build friend URL of front-end page.
	 * From https://github.com/BabDev/Podcast-Manager/blob/master/com_podcastmanager/admin/helpers/podcastmanager.php
	 *
	 * @param   string   $alias       The short URL's alias.
	 * @param   integer  $menuItemId  The ID of short URL menu item.
	 *
	 * @return  string
	 *
	 * @since   1.0.0
	 */
	public static function buildShortURL($alias, $menuItemId = null)
	{
		if ($menuItemId === null)
			$menuItemId = self::getMenuItemId();

		$url = 'index.php?option=com_cmshorturl&view=url&Itemid=' . $menuItemId . '&alias=' . $alias;

		// Get the router.
		$app = JApplication::getInstance('site');
		$router = $app->getRouter();

		// Make sure that we have our router.
		if (!$router)
		{
			return null;
		}

		if ((strpos($url, '&') !== 0) && (strpos($url, 'index.php') !== 0))
		{
			return $url;
		}

		// Build route.
		$uri = $router->build($url);
		$url = $uri->toString(array('path', 'query', 'fragment'));

		// Replace spaces.
		$url = preg_replace('/\s/u', '%20', $url);

		// Replace '/administrator'.
		$url = str_replace('/administrator', '', $url);

		// Strip .html, just in case.
		$url = str_replace('.html', '', $url);
		$url = htmlspecialchars($url);

		return $url;
	}

	/**
	 * Get menu item ID of short URL's front-end menu item.
	 *
	 * @return  integer
	 *
	 * @since   1.0.0
	 */
	public static function getMenuItemId()
	{
		$db = JFactory::getDbo();
		$query = $db->getQuery(true)
			->select($db->qn('id'))
			->from($db->qn('#__menu'))
			->where($db->qn('link') . ' = ' . $db->q('index.php?option=com_cmshorturl&view=url'))
			->where($db->qn('published') . ' = ' . $db->q('1'));

		return (int) $db->setQuery($query)->loadResult();
	}
}
