<?php
/**
 * @package     CMShortURL
 * @subpackage  com_cmshorturl
 * @copyright   Copyright (C) 2015 CMExtension Team http://www.cmext.vn/
 * @license     GNU General Public License version 2 or later
 */

defined('_JEXEC') or die;

/**
 * HTML utility class for com_cmshorturl.
 *
 * @package     CMShortURL
 * @subpackage  com_cmshorturl
 * @since       1.0.0
 */
abstract class JHtmlCMShortURL
{
	/**
	 * Display URL. Truncate URL if it is too long.
	 *
	 * @param   string  $url  URL.
	 *
	 * @return  string
	 *
	 * @since   1.0.0
	 */
	public static function url($url)
	{
		$limit = JComponentHelper::getParams('com_cmshorturl')->get('url_limit', 150);
		$html = '<span title="' . htmlspecialchars($url) . '">';

		if (strlen($url) > $limit && strpos($url, ' ', $limit) !== false)
		{
			$html .= mb_substr($url, 0, strpos($url, ' ', $limit)) . '...';
		}
		elseif (strlen($url) > $limit && strpos($url, ' ', $limit) === false)
		{
			$html .= mb_substr($url, 0, $limit) . '...';
		}
		else
		{
			$html .= $url;
		}

		$html .= '</span>';

		return $html;
	}

	/**
	 * Display browser and OS info.
	 *
	 * @param   string  $userAgent  User agent string.
	 *
	 * @return  string
	 *
	 * @since   1.0.0
	 */
	public static function userAgent($userAgent = '')
	{
		$html = '';

		if ($userAgent == '')
			return $html;

		require_once JPATH_ROOT . '/administrator/components/com_cmshorturl/helpers/BrowserDetection.php';

		$browser = new BrowserDetection($userAgent);
		$browserName = $browser->getBrowser();
		$platformName = $browser->getPlatform();

		$browserTitle = $browserName;
		$browserIcon = '';

		switch ($browserName)
		{
			case 'Chrome':
				$browserIcon = 'chrome';
				break;

			case 'Firefox':
				$browserIcon = 'firefox';
				break;

			case 'Internet Explorer':
			case 'Internet Explorer Mobile':
				$browserIcon = 'internet-explorer';
				break;

			case 'Opera':
			case 'Opera Mini':
			case 'Opera Mobile':
				$browserIcon = 'opera';
				break;

			case 'Safari':
				$browserIcon = 'safari';
				break;

			default:
				$browserIcon = 'globe';
		}

		$platformTitle = $platformName;
		$platformIcon = '';

		switch ($platformName)
		{
			case 'Android':
				$platformIcon = 'android';
				break;

			case 'iPad':
			case 'iPhone':
			case 'Macintosh':
				$platformIcon = 'apple';
				break;

			case 'Linux':
				$platformIcon = 'linux';
				break;

			case 'Windows':
			case 'Windows CE':
			case 'Windows Phone':
				$platformIcon = 'windows';
				break;

			default:
				$platformIcon = 'laptop';
		}

		$html .= '<i class="fa fa-fw fa-' . $browserIcon . '" title="' . $browserTitle . '"></i> ';
		$html .= '<i class="fa fa-fw fa-' . $platformIcon . '" title="' . $platformTitle . '"></i>';

		return $html;
	}
}
