<?php
/**
 * @package     CMShortURL
 * @subpackage  com_cmshorturl
 * @copyright   Copyright (C) 2015 CMExtension Team http://www.cmext.vn/
 * @license     GNU General Public License version 2 or later
 */

defined('_JEXEC') or die;

JFormHelper::loadFieldClass('calendar');

/**
 * Form field class to select date time for post schedule.
 *
 * @package     CMShortURL
 * @subpackage  com_cmshorturl
 * @since       1.0.0
 */
class JFormFieldCMSPSchedule extends JFormFieldCalendar
{
	/**
	 * The form field type.
	 *
	 * @var    string
	 * @since  1.0.0
	 */
	public $type = 'CMSPSchedule';

	/**
	 * Method to get the field input markup.
	 *
	 * @return  string  The field input markup.
	 *
	 * @since   1.0.0
	 */
	protected function getInput()
	{
		$html = array();
		$id = 'schedule_' . $this->id;

		$js = array();
		$js[] = "jQuery(document).ready(function () {";
		$js[] = "	jQuery('#" . $id . "').datetimepicker({";
		$js[] = "		format: 'yyyy-MM-dd hh:mm:ss'";
		$js[] = "	});";
		$js[] = "	if (MooTools != undefined) {";
		$js[] = "		var mHide = Element.prototype.hide;";
		$js[] = "		Element.implement({";
		$js[] = "			hide: function() {";
		$js[] = "				if (this.id == '" . $id . "') {";
		$js[] = "					return this;";
		$js[] = "				}";
		$js[] = "				mHide.apply(this, arguments);";
		$js[] = "			}";
		$js[] = "		});";
		$js[] = "	}";
		$js[] = "});";

		// Get some system objects.
		$config = JFactory::getConfig();
		$user = JFactory::getUser();

		// If a known filter is given use it.
		switch (strtoupper($this->filter))
		{
			case 'SERVER_UTC':
				// Convert a date to UTC based on the server timezone.
				if ((int) $this->value && $this->value != JFactory::getDbo()->getNullDate())
				{
					// Get a date object based on the correct timezone.
					$date = JFactory::getDate($this->value, 'UTC');
					$date->setTimezone(new DateTimeZone($config->get('offset')));

					// Transform the date string.
					$this->value = $date->format('Y-m-d H:i:s', true, false);
				}

				break;

			case 'USER_UTC':
				// Convert a date to UTC based on the user timezone.
				if ((int) $this->value && $this->value != JFactory::getDbo()->getNullDate())
				{
					// Get a date object based on the correct timezone.
					$date = JFactory::getDate($this->value, 'UTC');

					$date->setTimezone(new DateTimeZone($user->getParam('timezone', $config->get('offset'))));

					// Transform the date string.
					$this->value = $date->format('Y-m-d H:i:s', true, false);
				}

				break;
		}

		JHtml::_('bootstrap.framework');
		$doc = JFactory::getDocument();
		$doc->addScript('components/com_cmshorturl/assets/js/bootstrap-datetimepicker.js');
		$doc->addScriptDeclaration(implode("\n", $js));
		$doc->addStyleSheet('components/com_cmshorturl/assets/css/bootstrap-datetimepicker.css');

		$class = !empty($this->class) ? ' class="' . $this->class . '"' : '';

		$html[] = '<div id="' . $id . '" class="input-append">';
		$html[] = '	<input id="' . $this->id . '" name="' . $this->name . '" type="text" ' . $class . ' value="' . $this->value . '">';
		$html[] = '	<span class="add-on"><i data-time-icon="icon-clock" data-date-icon="icon-calendar"></i></span>';
		$html[] = '</div>';

		return implode($html);
	}
}
