<?php
/**
 * @package     CMShortURL
 * @subpackage  com_cmshorturl
 * @copyright   Copyright (C) 2015 CMExtension Team http://www.cmext.vn/
 * @license     GNU General Public License version 2 or later
 */

defined('_JEXEC') or die;

/**
 * Table class for source.
 *
 * @package     CMShortURL
 * @subpackage  com_cmshorturl
 * @since       1.0.0
 */
class CMShortURLTableSource extends JTable
{
	/**
	 * Constructor.
	 *
	 * @param   JDatabaseDriver  &$_db  Database connector object
	 *
	 * @since   1.0.0
	 */
	public function __construct(&$_db)
	{
		parent::__construct('#__cmshorturl_sources', 'id', $_db);
	}

	/**
	 * Overloaded check function.
	 *
	 * @return  boolean
	 *
	 * @since   1.0.0
	 */
	public function check()
	{
		$this->title = trim($this->title);
		$this->utm_source = trim($this->utm_source);

		if ($this->title == '')
		{
			$this->setError(JText::_('COM_CMSHORTURL_ERROR_SOURCE_EMPTY_TITLE'));

			return false;
		}

		if ($this->utm_source == '')
		{
			$this->setError(JText::_('COM_CMSHORTURL_ERROR_SOURCE_EMPTY_UTM_SOURCE'));

			return false;
		}

		$table = JTable::getInstance('Source', 'CMShortURLTable');

		if ($table->load(array('title' => $this->title)) && ($table->id != $this->id || $this->id == 0))
		{
			$this->setError(JText::sprintf('COM_CMSHORTURL_ERROR_SOURCE_DUPLICATED_TITLE', $this->title));

			return false;
		}

		return true;
	}

	/**
	 * Stores a record.
	 *
	 * @param   boolean  $updateNulls  True to update fields even if they are null.
	 *
	 * @return  boolean  True on success, false on failure.
	 *
	 * @since   1.0.0
	 */
	public function store($updateNulls = false)
	{
		$date = JFactory::getDate();
		$user = JFactory::getUser();

		if ($this->id)
		{
			$this->modified = $date->toSql();
			$this->modified_by = $user->get('id');
		}
		else
		{
			if (!(int) $this->created)
			{
				$this->created = $date->toSql();
			}

			if (empty($this->created_by))
			{
				$this->created_by = $user->get('id');
			}
		}

		return parent::store($updateNulls);
	}
}
