<?php
/**
 * @package     CMShortURL
 * @subpackage  com_cmshorturl
 * @copyright   Copyright (C) 2015 CMExtension Team http://www.cmext.vn/
 * @license     GNU General Public License version 2 or later
 */

defined('_JEXEC') or die;

/**
 * Table class for url.
 *
 * @package     CMShortURL
 * @subpackage  com_cmshorturl
 * @since       1.0.0
 */
class CMShortURLTableUrl extends JTable
{
	/**
	 * Constructor.
	 *
	 * @param   JDatabaseDriver  &$_db  Database connector object
	 *
	 * @since   1.0.0
	 */
	public function __construct(&$_db)
	{
		parent::__construct('#__cmshorturl_urls', 'id', $_db);
	}

	/**
	 * Overloaded check function.
	 *
	 * @return  boolean
	 *
	 * @since   1.0.0
	 */
	public function check()
	{
		$this->alias = trim($this->alias);
		$this->url = trim($this->url);

		$length = (int) JComponentHelper::getParams('com_cmshorturl')->get('random_alias_length', '5');

		if ($length <= 0)
			$length = 5;

		$table = JTable::getInstance('Url', 'CMShortURLTable');

		if ($this->alias == '')
		{
			$this->alias = CMShortURLHelper::generateRandomString($length);

			while ($table->load(array('alias' => $this->alias)) && ($table->id != $this->id || $this->id == 0))
			{
				$this->alias = CMShortURLHelper::generateRandomString($length);
			}
		}
		else
		{
			if ($table->load(array('alias' => $this->alias)) && ($table->id != $this->id || $this->id == 0))
			{
				$this->setError(JText::sprintf('COM_CMSHORTURL_ERROR_URL_DUPLICATED_ALIAS', $this->alias));

				return false;
			}
		}

		if ($this->url == '')
		{
			$this->setError(JText::_('COM_CMSHORTURL_ERROR_URL_EMPTY_URL'));

			return false;
		}

		return true;
	}

	/**
	 * Stores a record.
	 *
	 * @param   boolean  $updateNulls  True to update fields even if they are null.
	 *
	 * @return  boolean  True on success, false on failure.
	 *
	 * @since   1.0.0
	 */
	public function store($updateNulls = false)
	{
		$date = JFactory::getDate();
		$user = JFactory::getUser();

		if ($this->id)
		{
			$this->modified = $date->toSql();
			$this->modified_by = $user->get('id');
		}
		else
		{
			if (!(int) $this->created)
			{
				$this->created = $date->toSql();
			}

			if (empty($this->created_by))
			{
				$this->created_by = $user->get('id');
			}
		}

		$this->url = JStringPunycode::urlToPunycode($this->url);

		return parent::store($updateNulls);
	}
}
