<?php
/**
 * @package     CMShortURL
 * @subpackage  com_cmshorturl
 * @copyright   Copyright (C) 2015 CMExtension Team http://www.cmext.vn/
 * @license     GNU General Public License version 2 or later
 */

defined('_JEXEC') or die;

/**
 * View class for content form.
 *
 * @package     CMShortURL
 * @subpackage  com_cmshorturl
 * @since       1.0.0
 */
class CMShortURLViewContent extends JViewLegacy
{
	protected $state;

	protected $item;

	protected $form;

	/**
	 * Method to display the view.
	 *
	 * @param   string  $tpl  A template file to load. [optional]
	 *
	 * @return  mixed  A string if successful, otherwise a JError object.
	 *
	 * @since   1.0.0
	 */
	public function display($tpl = null)
	{
		// Initialiase variables.
		$this->form		= $this->get('Form');
		$this->item		= $this->get('Item');
		$this->state	= $this->get('State');
		$this->params	= $this->state->get('params');

		// Check for errors.
		if (count($errors = $this->get('Errors')))
		{
			JError::raiseError(500, implode("\n", $errors));

			return false;
		}

		$this->addToolbar();
		parent::display($tpl);
	}

	/**
	 * Add the page title and toolbar.
	 *
	 * @return  void
	 *
	 * @since   1.0.0
	 */
	protected function addToolbar()
	{
		JFactory::getApplication()->input->set('hidemainmenu', true);

		$user		= JFactory::getUser();
		$userId		= $user->get('id');
		$isNew		= ($this->item->id == 0);
		$checkedOut	= !($this->item->checked_out == 0 || $this->item->checked_out == $userId);
		$canDo		= JHelperContent::getActions('com_cmshorturl');

		JToolbarHelper::title($isNew ? JText::_('COM_CMSHORTURL_MANAGER_CONTENT_NEW') : JText::_('COM_CMSHORTURL_MANAGER_CONTENT_EDIT'), 'folder');

		// If not checked out, can save the item.
		if (!$checkedOut && ($canDo->get('core.edit') || $canDo->get('core.create')))
		{
			JToolbarHelper::apply('content.apply');
			JToolbarHelper::save('content.save');

			if ($canDo->get('core.create'))
			{
				JToolbarHelper::save2new('content.save2new');
			}
		}

		if (empty($this->item->id))
		{
			JToolbarHelper::cancel('content.cancel');
		}
		else
		{
			JToolbarHelper::cancel('content.cancel', 'JTOOLBAR_CLOSE');
		}
	}
}
