<?php
/**
 * @package     CMShortURL
 * @subpackage  com_cmshorturl
 * @copyright   Copyright (C) 2015 CMExtension Team http://www.cmext.vn/
 * @license     GNU General Public License version 2 or later
 */

defined('_JEXEC') or die;

/**
 * View class for source list.
 *
 * @package     CMShortURL
 * @subpackage  com_cmshorturl
 * @since       1.0.0
 */
class CMShortURLViewSources extends JViewLegacy
{
	protected $items;

	protected $pagination;

	protected $state;

	/**
	 * Method to display the view.
	 *
	 * @param   string  $tpl  A template file to load. [optional]
	 *
	 * @return  mixed  A string if successful, otherwise a JError object.
	 *
	 * @since   1.0.0
	 */
	public function display($tpl = null)
	{
		$this->items			= $this->get('Items');
		$this->pagination		= $this->get('Pagination');
		$this->state			= $this->get('State');
		$this->filterForm		= $this->get('FilterForm');
		$this->activeFilters	= $this->get('ActiveFilters');

		// Check for errors.
		if (count($errors = $this->get('Errors')))
		{
			JError::raiseError(500, implode("\n", $errors));

			return false;
		}

		CMShortURLHelper::addSubmenu('sources');

		$this->addToolbar();
		$this->sidebar = JHtmlSidebar::render();
		parent::display($tpl);
	}

	/**
	 * Add the page title and toolbar.
	 *
	 * @return  void
	 *
	 * @since   1.0.0
	 */
	protected function addToolbar()
	{
		$canDo = JHelperContent::getActions('com_cmshorturl');
		$user = JFactory::getUser();

		JToolbarHelper::title(JText::_('COM_CMSHORTURL_MANAGER_SOURCES'), 'folder');

		if ($canDo->get('core.create'))
		{
			JToolbarHelper::addNew('source.add');
		}

		if ($canDo->get('core.edit'))
		{
			JToolbarHelper::editList('source.edit');
		}

		if ($canDo->get('core.edit.state'))
		{
			JToolbarHelper::checkin('sources.checkin');
		}

		if ($canDo->get('core.delete'))
		{
			JToolbarHelper::deleteList('', 'sources.delete');
		}

		if ($user->authorise('core.admin', 'com_cmshorturl'))
		{
			JToolbarHelper::preferences('com_cmshorturl');
		}
	}
}
