<?php
/**
 * @package     CMShortURL
 * @subpackage  com_cmshorturl
 * @copyright   Copyright (C) 2015 CMExtension Team http://www.cmext.vn/
 * @license     GNU General Public License version 2 or later
 */

defined('_JEXEC') or die;

/**
 * Model class for url form.
 *
 * @package     CMShortURL
 * @subpackage  com_cmshorturl
 * @since       1.0.0
 */
class CMShortURLModelUrl extends JModelItem
{
	/**
	 * Method to auto-populate the model state.
	 *
	 * Note. Calling getState in this method will result in recursion.
	 *
	 * @return  void
	 *
	 * @since   1.0.0
	 */
	protected function populateState()
	{
		$app = JFactory::getApplication('site');

		// Load state from the request.
		$alias = $app->input->get('alias', 'html');
		$this->setState('url.alias', $alias);

		$params = $app->getParams();
		$this->setState('params', $params);
	}

	/**
	 * Method to get url data.
	 *
	 * @param   string  $alias  The alias of the url.
	 *
	 * @return  mixed
	 *
	 * @since   1.0.0
	 */
	public function &getItem($alias = '')
	{
		$alias = $this->getState('url.alias');

		if ($alias == '')
		{
			return array();
		}

		if ($this->_item === null)
		{
			$this->_item = array();
		}

		if (!isset($this->_item[$alias]))
		{
			try
			{
				$db = $this->getDbo();
				$query = $db->getQuery(true)
					->select($this->getState('item.select', 'a.id, a.alias, a.url, a.campaign_id, a.source_id, a.content_id'))
					->from($db->qn('#__cmshorturl_urls') . ' AS a')
					->where($db->qn('a.alias') . ' = ' . $db->q($alias));

				$query->select($db->qn('p.utm_campaign') . ' AS utm_campaign')
					->select($db->qn('p.utm_term') . ' AS utm_term')
					->select($db->qn('p.utm_medium') . ' AS utm_medium')
					->join('LEFT', $db->qn('#__cmshorturl_campaigns') . ' AS p ON '
						. $db->qn('p.id') . ' = ' . $db->qn('a.campaign_id')
					);

				$query->select($db->qn('s.utm_source') . ' AS utm_source')
					->join('LEFT', $db->qn('#__cmshorturl_sources') . ' AS s ON '
						. $db->qn('s.id') . ' = ' . $db->qn('a.source_id')
					);

				$query->select($db->qn('c.utm_content') . ' AS utm_content')
					->join('LEFT', $db->qn('#__cmshorturl_contents') . ' AS c ON '
						. $db->qn('c.id') . ' = ' . $db->qn('a.content_id')
					);

				$data = $db->setQuery($query)->loadObject();

				$this->_item[$alias] = $data;
			}
			catch (Exception $e)
			{
				$this->setError($e);
				$this->_item[$alias] = false;
			}
		}

		return $this->_item[$alias];
	}

	/**
	 * Method to update url's hits.
	 *
	 * @param   integer  $id  The id of the url.
	 *
	 * @return  void
	 *
	 * @since   1.0.0
	 */
	public function updateHits($id = 0)
	{
		if ((int) $id <= 0)
			return;

		$app = JFactory::getApplication();
		$hits = $app->getUserState('com_cmshorturl.hits', array());

		if (!in_array($id, $hits))
		{
			$db = $this->getDbo();
			$query = $db->getQuery(true)
				->update($db->quoteName('#__cmshorturl_urls'))
				->set($db->qn('hits') . ' = (' . $db->qn('hits') . ' + 1)')
				->where($db->qn('id') . ' = ' . $db->q((int) $id));
			$db->setQuery($query)->execute();

			$hits[] = $id;

			$app->setUserState('com_cmshorturl.hits', $hits);

			if ($this->state->get('params')->get('logging', 0))
			{
				$referer = $app->input->server->get('HTTP_REFERER', '', 'string');
				$userAgent = $app->input->server->get('HTTP_USER_AGENT', '', 'string');
				$address = $app->input->server->get('REMOTE_ADDR', '', 'string');
				$visited = JFactory::getDate()->toSql();

				JModelLegacy::getInstance('Log', 'CMShortURLModel')->log(
					$id,
					$referer,
					$userAgent,
					$address,
					$visited
				);
			}
		}
	}
}
