<?php
/**
 * @package     CMShortURL
 * @subpackage  com_cmshorturl
 * @copyright   Copyright (C) 2015 CMExtension Team http://www.cmext.vn/
 * @license     GNU General Public License version 2 or later
 */

defined('_JEXEC') or die;

/**
 * Routing class for com_cmshorturl component.
 *
 * @package     CMShortURL
 * @subpackage  com_cmshorturl
 * @since       1.0.0
 */
class CMShortURLRouter extends JComponentRouterBase
{
	/**
	 * Build the route.
	 *
	 * @param   array  &$query  An array of URL arguments
	 *
	 * @return  array  The URL arguments to use to assemble the subsequent URL.
	 *
	 * @since   1.0.0
	 */
	public function build(&$query)
	{
		$segments = array();

		if (isset($query['view']) && $query['view'] == 'url')
		{
			unset($query['view']);
		}

		if (isset($query['alias']))
		{
			$segments[] = $query['alias'];
			unset($query['alias']);
		}

		return $segments;
	}

	/**
	 * Parse the segments of a URL.
	 *
	 * @param   array  &$segments  The segments of the URL to parse.
	 *
	 * @return  array  The URL attributes to be used by the application.
	 *
	 * @since   1.0.0
	 */
	public function parse(&$segments)
	{
		$vars = array();

		if (isset($segments[0]))
		{
			$vars['view'] = 'url';
			$vars['alias'] = $segments[0];
		}

		return $vars;
	}
}

/**
 * Build the route for the com_cmshorturl component
 *
 * This function is a proxy for the new router interface
 * for old SEF extensions.
 *
 * @param   array  &$query  An array of URL arguments
 *
 * @return  array  The URL arguments to use to assemble the subsequent URL.
 *
 * @since   1.0.0
 */
function CMShortURLBuildRoute(&$query)
{
	$router = new CMShortURLRouter;

	return $router->build($query);
}

/**
 * Parse the segments of a URL.
 *
 * This function is a proxy for the new router interface
 * for old SEF extensions.
 *
 * @param   array  $segments  The segments of the URL to parse.
 *
 * @return  array  The URL attributes to be used by the application.
 *
 * @since   1.0.0
 */
function CMShortURLParseRoute($segments)
{
	$router = new CMShortURLRouter;

	return $router->parse($segments);
}
